# signaler

[![Build Status](https://travis-ci.org/ypcrts/signaler.svg?branch=master)](https://travis-ci.org/ypcrts/signaler?branch=master)
[![Coverage Status](https://coveralls.io/repos/github/ypcrts/signaler/badge.svg?branch=master)](https://coveralls.io/github/ypcrts/signaler?branch=master)
[![Latest PyPi Version](https://img.shields.io/pypi/v/signaler.svg)](https://pypi.python.org/pypi/signaler)

Simple (fool-proof) signal handling. 
